
/* Description: Initialization of SJA1000*/

#define SEND_BUFFER_FULL 0x80
#define MSG_SIZE 13 /* message size to define the querysize */
#define MAX_MSG 4 /* maximal message in Query */

//#include <interrupt.h>

#include "CAN_definitions.h"
#include "CAN_saj1000.h"
#include "ramconnect.h"

/*Globals*/
volatile SJAinit_t *pSJA_Init_Structure;
volatile u08 CANInterrupt = 0x00; /* For a copy of the Interrupt Register from the SJA1000 */
u08 Messages[MAX_MSG*MSG_SIZE]; /* One messages has 13byte and the temp is for 4 messages v */
u08 nextToSave = 0x00; /* says which is the next place in the messagesarray to save the msg */
u08 nextToSend = 0x00; /* says which msg from the messagearray is the next to send */
u08 MessagesInQuery = 0x00; /* says how many msg are in the query */

/*Send one message now without a query*/
void sendNow(Message_t* pMsg)
 {do{}while ((RD(StatusReg) & TBS_Bit) != TBS_Bit);
  /* write the msg in the buffer */
  WR(TxFrameInfo, pMsg->TxBuffer[0]);
  WR(TxBuffer1, pMsg->TxBuffer[1]);
  WR(TxBuffer2, pMsg->TxBuffer[2]);
  WR(TxBuffer3, pMsg->TxBuffer[3]);
  WR(TxBuffer4, pMsg->TxBuffer[4]);
  WR(TxBuffer5, pMsg->TxBuffer[5]);
  WR(TxBuffer6, pMsg->TxBuffer[6]);
  WR(TxBuffer7, pMsg->TxBuffer[7]);
  WR(TxBuffer8, pMsg->TxBuffer[8]);
  WR(TxBuffer9, pMsg->TxBuffer[9]);
  WR(TxBuffer10,pMsg->TxBuffer[10]);
  WR(TxBuffer11,pMsg->TxBuffer[11]);
  WR(TxBuffer12,pMsg->TxBuffer[12]);
  /* send */
  WR(CommandReg,TR_Bit);
 }

/*Send one message from the query*/
void send(void)
 {Message_t* pMsg; /* Pointer to the message to send */
  if((RD(StatusReg) & TCS_Bit) != TCS_Bit)
   {/* set the nextToSend one lower to the next msg */
    nextToSend--;
    if(nextToSend == 0xFF)
	 {nextToSend = MAX_MSG;
	 }
    /* set the messagecount */
    MessagesInQuery++;
    if(MessagesInQuery == MAX_MSG)
	 { MessagesInQuery = ClrByte;
	 }
   }
 /* check the TransmitBufferStatus if the Buffer is free send
 the msg if not enable the Interrupt and send wenn the Buffer is free */
 if((RD(StatusReg) & TBS_Bit) == TBS_Bit)
  {/* Set the messagepointer to the next msg to send */
   pMsg = (Message_t*)&Messages[nextToSend * MSG_SIZE];
   /* write the msg in the buffer */
   WR(TxFrameInfo, pMsg->TxBuffer[0]);
   WR(TxBuffer1, pMsg->TxBuffer[1]);
   WR(TxBuffer2, pMsg->TxBuffer[2]);
   WR(TxBuffer3, pMsg->TxBuffer[3]);
   WR(TxBuffer4, pMsg->TxBuffer[4]);
   WR(TxBuffer5, pMsg->TxBuffer[5]);
   WR(TxBuffer6, pMsg->TxBuffer[6]);
   WR(TxBuffer7, pMsg->TxBuffer[7]);
   WR(TxBuffer8, pMsg->TxBuffer[8]);
   WR(TxBuffer9, pMsg->TxBuffer[9]);
   WR(TxBuffer10,pMsg->TxBuffer[10]);
   WR(TxBuffer11,pMsg->TxBuffer[11]);
   WR(TxBuffer12,pMsg->TxBuffer[12]);
   /* send */
   WR(CommandReg,TR_Bit);
   /* set the nextToSend one higher to the next msg */
   nextToSend++;
   /* if the nextToSend is higher or have the same value like MAX_MSG set it 0x00 */
   if(nextToSend == MAX_MSG) 
   {nextToSend = ClrByte; 
   }
   /* set the messagecount one lower */
   MessagesInQuery--;
 }
}

/*set a message in a Query to send*/
void sendQuery(Message_t* pMessage)
 {Message_t* pMsg;
  /* wait while the SendBufferFull Bit is set (tempbuffer full) */
  while(MessagesInQuery >= MAX_MSG)
   {}
  /* set the messagepointer to the next place to save the msg */
  pMsg = (Message_t*)&Messages[nextToSave * MSG_SIZE];
  /* save the msg in the tempbuffer on the atmel */
  pMsg->TxBuffer[0] = pMessage->TxBuffer[0];
  pMsg->TxBuffer[1] = pMessage->TxBuffer[1];
  pMsg->TxBuffer[2] = pMessage->TxBuffer[2];
  pMsg->TxBuffer[3] = pMessage->TxBuffer[3];
  pMsg->TxBuffer[4] = pMessage->TxBuffer[4];
  pMsg->TxBuffer[5] = pMessage->TxBuffer[5];
  pMsg->TxBuffer[6] = pMessage->TxBuffer[6];
  pMsg->TxBuffer[7] = pMessage->TxBuffer[7];
  pMsg->TxBuffer[8] = pMessage->TxBuffer[8];
  pMsg->TxBuffer[9] = pMessage->TxBuffer[9];
  pMsg->TxBuffer[10] = pMessage->TxBuffer[10];
  pMsg->TxBuffer[11] = pMessage->TxBuffer[11];
  pMsg->TxBuffer[12] = pMessage->TxBuffer[12];
  /* set the messagecounter one higher */
  MessagesInQuery++;
  /* set the nextToSave one higher */
  nextToSave++;
  /* if the nextToSave is higher or have the same value like MAX_MSG set it 0x00 */
  if(nextToSave >= MAX_MSG)
   {nextToSave = ClrByte;
   }
  /* check the TransmitBufferStatus if the Buffer is free send
  the msg if not enable the Interrupt and send wenn the Buffer is free */
  if((RD(StatusReg) & TBS_Bit) == TBS_Bit)
   {send();
   }
}

/*Configure the Bustiming*/
void setTiming()
 {switch(pSJA_Init_Structure->Timing)
 { case T100k16: //bit-rate = 100kBit/s @ 16 MHz, the bus is sampled once 
   {WR(BusTiming0Reg, SJW_kB_16 | Presc_kB_16);
    WR(BusTiming1Reg, TSEG2_kB_16 | TSEG1_kB_16);
   };break;
 case T100k24: //bit-rate = 100kBit/s @ 24 MHz, the bus is sampled once  
  {WR(BusTiming0Reg, SJW_kB_24 | Presc_kB_24);
   WR(BusTiming1Reg, TSEG2_kB_24 | TSEG1_kB_24);
   };break;
 case T250k24: // bit-rate = 250kBit/s @ 24 MHz, the bus is sampled once 
  {WR(BusTiming0Reg, SJWExample | PrescExample);
   WR(BusTiming1Reg, TSEG2Example | TSEG1Example);
  };break;
 case T1M16:// bit-rate = 1 Mbit/s @ 16 MHz, the bus is sampled once 
  {WR(BusTiming0Reg, SJW_MB_16 | Presc_MB_16);
   WR(BusTiming1Reg, TSEG2_MB_16 | TSEG1_MB_16);
   };break;
 case T1M24: // bit-rate = 1 Mbit/s @ 24 MHz, the bus is sampled once
  {WR(BusTiming0Reg, SJW_MB_24 | Presc_MB_24);
   WR(BusTiming1Reg, TSEG2_MB_24 | TSEG1_MB_24);
  };break; 
  
 default:{};break;
}
}

/*Initialization of the SJA1000 by the SJAInitReg*/
void initSJA(SJAinit_t *x)
 {/* set the global pointer to the initstructure */
  pSJA_Init_Structure = x;
  /* ---------- start of Initialization of the SJA1000 ---------- */
  /* set reset mode/request (Note:after power-on SJA1000 is in BasicCAN
  mode) leave loop after a time out signal an error */
  
  
  while((RD(ModeControlReg) & RM_RR_Bit) == ClrByte)
   {//* other bits that the reset mode/request bit are unchanged 
    WR(ModeControlReg, (RD(ModeControlReg) | RM_RR_Bit));
    // other bits that the reset mode/request bit are unchanged 
   }
  
    /* ext. Transciever is used, Clockoutput is off, set to PelicanMode */
  WR(ClockDivideReg, (CBP_Bit | ClkOff_Bit | CANMode_Bit)); 
  /* disable CAN interrupts, if request (always necessary after power-on
  (write to SJA1000 Interrupt Enable / Control Reg.) */
  WR(InterruptEnReg, ClrIntEnSJA);
  /* Configure the Acception Code & Mask form the initstructure */
  WR(AcceptCode0Reg, pSJA_Init_Structure->ACR[0]);
  WR(AcceptCode1Reg, pSJA_Init_Structure->ACR[1]);
  WR(AcceptCode2Reg, pSJA_Init_Structure->ACR[2]);
  WR(AcceptCode3Reg, pSJA_Init_Structure->ACR[3]);
  WR(AcceptMask0Reg, pSJA_Init_Structure->AMR[0]);
  WR(AcceptMask1Reg, pSJA_Init_Structure->AMR[1]);
  WR(AcceptMask2Reg, pSJA_Init_Structure->AMR[2]);
  WR(AcceptMask3Reg, pSJA_Init_Structure->AMR[3]);
  /* set the bus timing values also from the initstructure */
  setTiming();
  /* configure CAN outputs: float on TX1, Push/Pull on TX0, normale outputmode */
  WR(OutControlReg, Tx1Float | Tx0PshPull | NormalMode);
  /* leave the reset mode and enter to the operating mode. For that clear
  Reset Mode bit. */
  do
   {/* wait until the RM_RR_Bit is cleared */
    /* break loop after a time out and signal an error Exit Reset Mode
    and enter new Mode (Listen Only, Normal, ... ) */
    WR(ModeControlReg, pSJA_Init_Structure->Mode);
   }while((RD(ModeControlReg) & RM_RR_Bit) != ClrByte);
  /* ----------- end of Initialization of the SJA1000 ------------ */
  /* enable the Interrupt on the SJA1000 like settings form the initstruc. */
  WR(InterruptEnReg, pSJA_Init_Structure->InterruptEnable);
}

/*Interrupt1 signal on PD3 which is conected to the SJA1000*/
Interrupt_for_CAN()
 {/* Save the Interrupt Register because the informatin will be lost with the fist reading. */
  CANInterrupt = RD(InterruptReg);
  /* Check the Receive Interrupt Flag in the Interrupt Reg. */
  if((CANInterrupt & RI_Bit) != ClrByte)
   {/* Check the buffer and read all msg */
    do{/* Check for a RTR message */
       if((RD(RxFrameInfo) & 0x40) != ClrByte)
	    {/* It was a RTR message */
         sendRTRMessage();
		}
       else
	    {/* It was not a RTR message */
         receive();
		}
       WR(CommandReg,(RD(CommandReg)|RRB_Bit)); /* Release Receive Buffer */
      }while((RD(StatusReg) & RBS_Bit) != ClrByte);
   }
 /* Check the Transmit Interrupt Flag in the Interrupt Reg. */
 if((CANInterrupt & TI_Bit) != ClrByte)
  {if(MessagesInQuery != ClrByte)
   {send();
   }
  }
 /* Check the Error Warning Interrupt Flag in the Interrupt Reg. */
 if((CANInterrupt & DOI_Bit) != ClrByte)
  {receiveDataOverrun();
   WR(CommandReg,(RD(CommandReg)|CDO_Bit)); /* Release Receive Buffer */
  }
 /* Check the Error Warning Interrupt Flag in the Interrupt Reg. */
 if((CANInterrupt & EI_Bit) != ClrByte)
  {unsupportedIE();
  }
 /* Check the Error Passive Interrupt Flag in the Interrupt Reg. */
 if((CANInterrupt & EPI_Bit) != ClrByte)
  {passivError();
  }
 /* Check the Wake-Up Interrupt Flag in the Interrupt Reg. */
 if((CANInterrupt & WUI_Bit) != ClrByte)
  {unsupportedIE();
  }
 /* Check the Arbitration Lost Interrupt Flag in the Interrupt Reg. */
 if((CANInterrupt & ALI_Bit) != ClrByte)
  {arbitrationLost();
  }
 /* Check the Bus Error Interrupt Flag in the Interrupt Register */
 if((CANInterrupt & BEI_Bit) != ClrByte)
 {busError();
 }
return 0x00;
}


/*returns the value of the last interrupt*/
u08 getCanIE(void)
 {return CANInterrupt;
 }
void receiveDataOverrun()
 {show(3,getCanIE());
 }
/** Unsupported interrupt*/
void unsupportedIE()
 {show(3,getCanIE());
 }
/*Message was lost*/
void arbitrationLost()
 {show(3,getCanIE());
 }
/*Buserror*/
void busError()
 {show(3,getCanIE());
 }
/*PassiveError*/
void passivError()
 {show(3,getCanIE());
 }
/*Something for debuging*/
void show(u08 pos,u08 value)
 {//show value to LCD
 }
 void getDistanz(){}
