
#define PeliCANMode 1

/* address and bit definitions for the Mode & Control Register */
#define ModeControlReg 0
#define RM_RR_Bit 0x01 /* reset mode (request) bit */
#if defined (PeliCANMode)  /* **** PeliCAN mode **** */
#define LOM_Bit 0x02 /* listen only mode bit */
#define STM_Bit 0x04 /* self test mode bit */
#define AFM_Bit 0x08 /* acceptance filter mode bit */
#define SM_Bit 0x10 /* enter sleep mode bit */
#endif /* end define (PeliCANMode) */

/* address and bit definitions for the Interrupt Enable & Control Register*/

#if defined (PeliCANMode) /* **** PeliCAN mode **** */
#define InterruptEnReg 4 /* Interupt Enable Register */
#define RIE_Bit 0x01 /* receive interrupt enablebit */
#define TIE_Bit 0x02 /* transmit interrupt enable bit */
#define EIE_Bit 0x04 /* error warning interrupt enable bit */
#define DOIE_Bit 0x08 /* data overrun interrupt enable bit */
#define WUIE_Bit 0x10 /* wake-up interrupt enable bit */
#define EPIE_Bit 0x20 /* error passive interrupt enable bit */
#define ALIE_Bit 0x40 /* arbitration lost interr. enable bit */
#define BEIE_Bit 0x80 /* bus error interrupt enable bit */
#else /* **** BasicCAN mode **** */
#define InterruptEnReg 0 /* Control Register */
#define RIE_Bit 0x02 /* Receive Interrupt enable bit */
#define TIE_Bit 0x04 /* Transmit Interrupt enable bit */
#define EIE_Bit 0x08 /* Error Interrupt enable bit */
#define DOIE_Bit 0x10 /* Overrun Interrupt enable bit */
#endif /* end define (PeliCANMode) or (BasicCANMode) */

/* address and bit definitions for the Command Register */
#define CommandReg 1 /* Command Register */
#define TR_Bit 0x01 /* transmission request bit */
#define AT_Bit 0x02 /* abort transmission bit */
#define RRB_Bit 0x04 /* release receive buffer bit */
#define CDO_Bit 0x08 /* clear data overrun bit */
#if defined (PeliCANMode) /* **** PeliCAN mode **** */
#define SRR_Bit 0x10 /* self reception request bit */
#else /* **** BasicCAN mode **** */
#define GTS_Bit 0x10 /* goto sleep bit (BasicCAN mode) */
#endif /* end define (PeliCANMode) or (BasicCANMode) */

/* address and bit definitions for the Status Register */
#define StatusReg 2 /* Status Register */
#define RBS_Bit 0x01 /* receive buffer status bit */
#define DOS_Bit 0x02 /* data overrun status bit */
#define TBS_Bit 0x04 /* transmit buffer status bit */
#define TCS_Bit 0x08 /* transmission complete status bit */
#define RS_Bit 0x10 /* receive status bit */
#define TS_Bit 0x20 /* transmit status bit */
#define ES_Bit 0x40 /* error status bit */
#define BS_Bit 0x80 /* bus status bit */




/* address and bit definitions for the Interrupt Register */
#define InterruptReg 3 /* Interrupt Register */
#define RI_Bit 0x01 /* receive interrupt bit */
#define TI_Bit 0x02 /* transmit interrupt bit */
#define EI_Bit 0x04 /* error warning interrupt bit */
#define DOI_Bit 0x08 /* data overrun interrupt bit */
#define WUI_Bit 0x10 /* wake-up interrupt bit */
#if defined (PeliCANMode) /* **** PeliCAN mode **** */
#define EPI_Bit 0x20 /* error passive interrupt bit */
#define ALI_Bit 0x40 /* arbitration lost interrupt bit */
#define BEI_Bit 0x80 /* bus error interrupt bit */
#endif /* end define (PeliCANMode */


/* address and bit definitions for the Bus Timing Registers */
#define BusTiming0Reg 6 /* Bus Timing 0 Register */
#define BusTiming1Reg 7 /* Bus Timing 1 Register */
#define SAM_Bit 0x80 /* sample mode bit 1 == the bus is sampled 3 times 0 == the bus is sampled once */
/* address and bit definitions for the Output Control Register */
#define OutControlReg 8 /* Output Control Register */
/* OCMODE1, OCMODE0 */
#define BiPhaseMode 0x00 /* bi-phase output mode */
#define NormalMode 0x02 /* normal output mode */
#define ClkOutMode 0x03 /* clock output mode */

/* output pin configuration for TX1 */
#define OCPOL1_Bit 0x20 /* output polarity control bit */
#define Tx1Float 0x00 /* configured as float */
#define Tx1PullDn 0x40 /* configured as pull-down */
#define Tx1PullUp 0x80 /* configured as pull-up */
#define Tx1PshPull 0xC0 /* configured as push/pull */
/* output pin configuration for TX0 */
#define OCPOL0_Bit 0x04 /* output polarity control bit */
#define Tx0Float 0x00 /* configured as float */
#define Tx0PullDn 0x08 /* configured as pull-down */
#define Tx0PullUp 0x10 /* configured as pull-up */
#define Tx0PshPull 0x18 /* configured as push/pull */

/* address definitions of Acceptance Code & Mask Registers */
#if defined (PeliCANMode) /* **** PeliCAN mode **** */
#define AcceptCode0Reg 16 /* Acceptance Code 0 Register */
#define AcceptCode1Reg 17 /* Acceptance Code 1 Register */
#define AcceptCode2Reg 18 /* Acceptance Code 2 Register */
#define AcceptCode3Reg 19 /* Acceptance Code 3 Register */
#define AcceptMask0Reg 20 /* Acceptance Mask 0 Register */
#define AcceptMask1Reg 21 /* Acceptance Mask 1 Register */
#define AcceptMask2Reg 22 /* Acceptance Mask 2 Register */
#define AcceptMask3Reg 23 /* Acceptance Mask 3 Register */
#else /* **** BasicCAN mode **** */
#define AcceptCodeReg 4 /* Acceptance Code 0 Register */
#define AcceptMaskReg 5 /* Acceptance Mask 0 Register */
#endif /* end define (PeliCANMode) or (BasicCANMode) */


/* address definitions of the Rx-Buffer */
#if defined (PeliCANMode) /* **** PeliCAN mode **** */
#define RxFrameInfo 16
#define RxBuffer1 17
#define RxBuffer2 18
#define RxBuffer3 19
#define RxBuffer4 20
#define RxBuffer5 21
#define RxBuffer6 22
#define RxBuffer7 23
#define RxBuffer8 24
#define RxBuffer9 25
#define RxBuffer10 26
#define RxBuffer11 27
#define RxBuffer12 28
#else /* **** BasicCAN mode **** */
#define RxBuffer1 20
#define RxBuffer2 21
#define RxBuffer3 22
#define RxBuffer4 23
#define RxBuffer5 24
#define RxBuffer6 25
#define RxBuffer7 26
#define RxBuffer8 27
#define RxBuffer9 28
#define RxBuffer10 29
#endif /* end define (PeliCANMode) or (BasicCANMode) */



/* address definitions of the Tx-Buffer */
#if defined (PeliCANMode) /* **** PeliCAN mode **** */
/* write only addresses */
#define TxFrameInfo 16
#define TxBuffer1 17
#define TxBuffer2 18
#define TxBuffer3 19
#define TxBuffer4 20
#define TxBuffer5 21
#define TxBuffer6 22
#define TxBuffer7 23
#define TxBuffer8 24
#define TxBuffer9 25
#define TxBuffer10 26
#define TxBuffer11 27
#define TxBuffer12 28


/* read only addresses */
#define TxFrameInfoRd 96
#define TxBufferRd1 97
#define TxBufferRd2 98
#define TxBufferRd3 99
#define TxBufferRd4 100
#define TxBufferRd5 101
#define TxBufferRd6 102
#define TxBufferRd7 103
#define TxBufferRd8 104
#define TxBufferRd9 105
#define TxBufferRd10 106
#define TxBufferRd11 107
#define TxBufferRd12 108
#else /* **** BasicCAN mode **** */
#define TxBuffer1 10
#define TxBuffer2 11
#define TxBuffer3 12
#define TxBuffer4 13
#define TxBuffer5 14
#define TxBuffer6 15
#define TxBuffer7 16
#define TxBuffer8 17
#define TxBuffer9 18
#define TxBuffer10 19
#endif /* end define (PeliCANMode) or (BasicCANMode) */

/* address definitions of Other Registers */
#if defined (PeliCANMode) /* **** PeliCAN mode **** */
#define ArbLostCapReg 11 /* Arbitration Lost Capture Register */
#define ErrCodeCapReg 12 /* Error Code Capture Register */
#define ErrWarnLimitReg 13 /* Error Warning Limit Register */
#define RxErrCountReg 14 /* RX Error Counter Register */
#define TxErrCountReg 15 /* TX Error Counter Register */
#define RxMsgCountReg 29 /* RX Message Counter Register */
#define RxBufStartAdr 30 /* RX Buffer Start Address Register */
#endif /* end define (PeliCANMode) */

/* address and bit definitions for the Clock Divider Register */
#define ClockDivideReg 31 /* Clock Divider Register */
#define DivBy1 0x07 /* CLKOUT = oscillator frequency */
#define DivBy2 0x00 /* CLKOUT = 1/2 oscillator frequency */
#define ClkOff_Bit 0x08 /* clock off bit,control of the CLK OUT pin */
#define RXINTEN_Bit 0x20 /* pin TX1 used for receive interrupt */
#define CBP_Bit 0x40 /* CAN comparator bypass control bit */
#define CANMode_Bit 0x80 /* CAN mode definition bit */
