//Description: Initialization of SJA1000

/* Mode */
#define ResetMode 0x01 /* 0000 0001 */
#define ListenOnlyMode 0x02 /* 0000 0010 */
#define SelfTestMode 0x04 /* 0000 0100 */
#define AcceptionFilterMode 0x08 /* 0000 1000 */
#define SleepMode 0x10 /* 0001 0000 */

/* Timing */
#define T100k16 0x01 /* bit-rate = 100kBit/s @ 16 MHz */
#define T100k24 0x02 /* bit-rate = 100kBit/s @ 24 MHz */
#define T250k24 0x04 /* bit-rate = 250kBit/s @ 24 MHz */
#define T1M16 0x08 /* bit-rate = 1MBit/s @ 16 MHz */
#define T1M24 0x10 /* bit-rate = 1MBit/s @ 24 MHz */

/* Message */
#define ExtendedFrameFormat 0x80 /* EFF extended frame format */

/* Structure to Initialize the CAN SJA1000 Controller */
typedef struct
{
uint8_t Timing; /* Timing for the SJA1000 */
uint8_t ACR[4]; /* AcceptionCodes */
uint8_t AMR[4]; /* AcceptionMasks */
uint8_t Mode; /* Mode after the initializition */
uint8_t InterruptEnable; /* Enable the Interrupts on the SAJ1000
for details look into definitions.h */
}SJAinit_t;

/* Structure to handle a Message */
typedef struct{uint8_t TxBuffer[13];}Message_t;

/* Prototypes */
uint8_t getCanIE(void); /* Returns the Interruptregister form SJA*/
void initSJA(SJAinit_t*); /* Initialization of the Controller */
void receiveDataOverrun(void); /* Prototype the FIFO is full data lost */
void unsupportedIE(void); /* Unsupportede interrupt was goiong */
void arbitrationLost(void); /* Is called when a message lost */
void busError(void); /* Buserror */
void passivError(void); /* Passive Interrupt */
void receive(void); /* Prototype to receive the msg */
void show(uint8_t,uint8_t); /* Prototype for debuging */
void sendQuery(Message_t*); /* Prototype to send a msg */
void sendNow(Message_t*); /* Prototype to send a msg without a query*/
void sendRTRMessage(void); /* Prototype to send the request for a RTR message */